# Pad Thai

Make Pad Thai from few-shot learning 😉.

PadThai is a language model tool with an application for few-shot learning for Thai Language.

- Original code from: https://link.medium.com/4FfbALWz8gb
- Documentation: https://pythainlp.github.io/padthai/
- Tutorials: https://github.com/PyThaiNLP/padthai/tree/main/notebooks

## Install

``` sh
pip install padthai
```

## Support Model

- [GPT-Neo](https://huggingface.co/EleutherAI) - GPT-Neo is a transformer model designed using EleutherAI's replication of the GPT-3 architecture.
- [ThaiGPT-Next](https://github.com/wannaphong/thaigpt-next) - It is fine-tune the GPT-Neo model for Thai language.
- [Flax GPT-2 model](https://huggingface.co/flax-community/gpt2-base-thai) - It's GPT-2 model. It was trained on the OSCAR dataset

## Requirements

``` sh
transformers<5.0
```

## License

Apache-2.0 License
